import argparse
from julia_rings.rings import ring_statistics
from ase.io import read
import time
import numpy as np

parser = argparse.ArgumentParser(description="Ring Statistics Script")
parser.add_argument("input_file", help="Input file in ASE-supported format")
parser.add_argument("-v", "--verbosity", help="Verbosity level 0, 1", default=0)
parser.add_argument("-o", "--output", help="Output file name", default="rings_stats.npy")
parser.add_argument("--maxpths", help="Maximum number of paths to consider at each node", default=1000)
parser.add_argument("--maxlvl", help="Rings of size up to 2*maxlvl can be found", default=12)
args = parser.parse_args()

v = int(args.verbosity)

ats = read(args.input_file, "-1")
print(ats.symbols)
num_atom=len(ats)
st = time.time()

rs, rings = ring_statistics(ats, verbosity=v, mxpths=int(args.maxpths), outfile=args.output, maxlvl=int(args.maxlvl),cutoff=2.85)

print("rs",rs)
# print("rings",type(rings))
# print("rings",rings[1])
# print("rings",rings[4])
# print("rings",rings[2])

# print("rings",rings)

np.savetxt('rings_stats.npy', rs)

import numpy as np
import matplotlib.pyplot as plt

ring_size=np.linspace(1,24,24)

plt.figure(figsize=[10,5])
rs=rs/num_atom
plt.plot(ring_size,rs,'-s',
        markerfacecolor='none' )

plt.xlim([1.5,13.5])
plt.title("Ring Statistics of "+str(ats.symbols))
plt.xlabel("Ring Size")
plt.ylabel("Count / $atom^{-1}$")
plt.legend()

plt.savefig(args.input_file+".png",dpi = 300, transparent=True )

et = time.time()

elapsed = et - st
print(f"Elapsed time: {elapsed:.2f} seconds")
